@@ -37,6 +37,8 @@ typedef struct __pacdb_t {
 
 pacdb_t* db_open(char *root, char *dbpath, char *treename);
 void db_close(pacdb_t *db);
+int db_getlastupdate(const char *dbpath, char *ts);
+int db_setlastupdate(const char *dbpath, const char *ts);
 PMList* db_loadpkgs(pacdb_t *db);
 pkginfo_t* db_scan(pacdb_t *db, char *target, unsigned int inforeq);
 pkginfo_t* db_read(pacdb_t *db, struct dirent *ent, unsigned int inforeq);
